QScintilla/QsciScintillaCompat.py

changeset 3176
51feb6174cc2
parent 3169
7b1b754a60a6
child 3178
f25fc1364c88
child 3215
6c5877c48067
--- a/QScintilla/QsciScintillaCompat.py	Sun Jan 05 15:20:02 2014 +0100
+++ b/QScintilla/QsciScintillaCompat.py	Sun Jan 05 17:13:21 2014 +0100
@@ -1195,29 +1195,33 @@
         """
         return QsciScintillaBase.event(self, evt)
     
-    def inputMethodEvent(self, evt):
-        """
-        Protected method to cope with a glitch in some Qscintilla versions
-        handling input events.
-        
-        Note: This simply disables the Qscintilla behavior.
+    # TODO: adjust this once we have a working QScintilla version
+    if "inputMethodEvent" in QsciScintillaBase.__dict__ and \
+            QSCINTILLA_VERSION() < 0x020900:
+        def inputMethodEvent(self, evt):
+            """
+            Protected method to cope with a glitch in some Qscintilla versions
+            handling input events.
+            
+            Note: This simply disables the Qscintilla behavior.
+            
+            @param evt reference to the input method event object
+                (QInputMethodEvent)
+            """
+            pass
         
-        @param evt reference to the input method event object
-            (QInputMethodEvent)
-        """
-        pass
-    
-    def inputMethodQuery(self, query):
-        """
-        Protected method to cope with a glitch in some Qscintilla versions
-        handling input events.
-        
-        Note: This simply disables the Qscintilla behavior.
-        
-        @param query reference to the input method query object
-            (Qt.InputMethodQuery)
-        """
-        pass
+        def inputMethodQuery(self, query):
+            """
+            Protected method to cope with a glitch in some Qscintilla versions
+            handling input events.
+            
+            Note: This simply disables the Qscintilla behavior.
+            
+            @param query reference to the input method query object
+                (Qt.InputMethodQuery)
+            @return object containing the requested information
+            """
+            return None
 
     ###########################################################################
     ## interface methods to the mini editor

eric ide

mercurial